# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RouteArgs', 'Route']

@pulumi.input_type
class RouteArgs:
    def __init__(__self__, *,
                 actions: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 expression: pulumi.Input[_builtins.str],
                 priority: pulumi.Input[_builtins.int],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Route resource.
        :param pulumi.Input[_builtins.str] expression: A filter expression like `match_recipient('.*@gmail.com')`
        :param pulumi.Input[_builtins.int] priority: Smaller number indicates higher priority. Higher priority routes are handled first.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        """
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "priority", priority)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def actions(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "actions", value)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> pulumi.Input[_builtins.str]:
        """
        A filter expression like `match_recipient('.*@gmail.com')`
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "expression", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Input[_builtins.int]:
        """
        Smaller number indicates higher priority. Higher priority routes are handled first.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _RouteState:
    def __init__(__self__, *,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Route resources.
        :param pulumi.Input[_builtins.str] expression: A filter expression like `match_recipient('.*@gmail.com')`
        :param pulumi.Input[_builtins.int] priority: Smaller number indicates higher priority. Higher priority routes are handled first.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        """
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expression is not None:
            pulumi.set(__self__, "expression", expression)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "actions", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def expression(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A filter expression like `match_recipient('.*@gmail.com')`
        """
        return pulumi.get(self, "expression")

    @expression.setter
    def expression(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expression", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Smaller number indicates higher priority. Higher priority routes are handled first.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("mailgun:index/route:Route")
class Route(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a Mailgun Route resource. This can be used to create and manage routes on Mailgun.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_mailgun as mailgun

        # Create a new Mailgun route
        default = mailgun.Route("default",
            priority=0,
            description="inbound",
            expression="match_recipient('.*@foo.example.com')",
            actions=[
                "forward('http://example.com/api/v1/foos/')",
                "stop()",
            ])
        ```

        ## Import

        Routes can be imported using `ROUTE_ID` and `region` via `import` command. Route ID can be found on Mailgun portal in section `Receiving/Routes`. Region has to be chosen from `eu` or `us` (when no selection `us` is applied).

        hcl

        ```sh
        $ pulumi import mailgun:index/route:Route test eu:123456789
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] expression: A filter expression like `match_recipient('.*@gmail.com')`
        :param pulumi.Input[_builtins.int] priority: Smaller number indicates higher priority. Higher priority routes are handled first.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RouteArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Mailgun Route resource. This can be used to create and manage routes on Mailgun.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_mailgun as mailgun

        # Create a new Mailgun route
        default = mailgun.Route("default",
            priority=0,
            description="inbound",
            expression="match_recipient('.*@foo.example.com')",
            actions=[
                "forward('http://example.com/api/v1/foos/')",
                "stop()",
            ])
        ```

        ## Import

        Routes can be imported using `ROUTE_ID` and `region` via `import` command. Route ID can be found on Mailgun portal in section `Receiving/Routes`. Region has to be chosen from `eu` or `us` (when no selection `us` is applied).

        hcl

        ```sh
        $ pulumi import mailgun:index/route:Route test eu:123456789
        ```

        :param str resource_name: The name of the resource.
        :param RouteArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RouteArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 expression: Optional[pulumi.Input[_builtins.str]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RouteArgs.__new__(RouteArgs)

            if actions is None and not opts.urn:
                raise TypeError("Missing required property 'actions'")
            __props__.__dict__["actions"] = actions
            __props__.__dict__["description"] = description
            if expression is None and not opts.urn:
                raise TypeError("Missing required property 'expression'")
            __props__.__dict__["expression"] = expression
            if priority is None and not opts.urn:
                raise TypeError("Missing required property 'priority'")
            __props__.__dict__["priority"] = priority
            __props__.__dict__["region"] = region
        super(Route, __self__).__init__(
            'mailgun:index/route:Route',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            actions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            expression: Optional[pulumi.Input[_builtins.str]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'Route':
        """
        Get an existing Route resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] expression: A filter expression like `match_recipient('.*@gmail.com')`
        :param pulumi.Input[_builtins.int] priority: Smaller number indicates higher priority. Higher priority routes are handled first.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RouteState.__new__(_RouteState)

        __props__.__dict__["actions"] = actions
        __props__.__dict__["description"] = description
        __props__.__dict__["expression"] = expression
        __props__.__dict__["priority"] = priority
        __props__.__dict__["region"] = region
        return Route(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def actions(self) -> pulumi.Output[Sequence[_builtins.str]]:
        return pulumi.get(self, "actions")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def expression(self) -> pulumi.Output[_builtins.str]:
        """
        A filter expression like `match_recipient('.*@gmail.com')`
        """
        return pulumi.get(self, "expression")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[_builtins.int]:
        """
        Smaller number indicates higher priority. Higher priority routes are handled first.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DomainCredentialArgs', 'DomainCredential']

@pulumi.input_type
class DomainCredentialArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[_builtins.str],
                 login: pulumi.Input[_builtins.str],
                 password: pulumi.Input[_builtins.str],
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DomainCredential resource.
        :param pulumi.Input[_builtins.str] domain: The domain to add credential of Mailgun.
        :param pulumi.Input[_builtins.str] login: The local-part of the email address to create.
        :param pulumi.Input[_builtins.str] password: Password for user authentication.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "login", login)
        pulumi.set(__self__, "password", password)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Input[_builtins.str]:
        """
        The domain to add credential of Mailgun.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter
    def login(self) -> pulumi.Input[_builtins.str]:
        """
        The local-part of the email address to create.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "login", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Input[_builtins.str]:
        """
        Password for user authentication.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _DomainCredentialState:
    def __init__(__self__, *,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 login: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DomainCredential resources.
        :param pulumi.Input[_builtins.str] domain: The domain to add credential of Mailgun.
        :param pulumi.Input[_builtins.str] login: The local-part of the email address to create.
        :param pulumi.Input[_builtins.str] password: Password for user authentication.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        """
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if login is not None:
            pulumi.set(__self__, "login", login)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain to add credential of Mailgun.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The local-part of the email address to create.
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "login", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for user authentication.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("mailgun:index/domainCredential:DomainCredential")
class DomainCredential(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 login: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a Mailgun domain credential resource. This can be used to create and manage credential in domain of Mailgun.

        > **Note:** Please note that starting of v0.6.1 due to using new Mailgun Client API (v4), there is no possibility to retrieve previously created secrets via API. In order get it worked, it's recommended to mark `password` as ignored under `lifecycle` block. See below.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_mailgun as mailgun

        # Create a new Mailgun credential
        foobar = mailgun.DomainCredential("foobar",
            domain="toto.com",
            login="test",
            password="supersecretpassword1234",
            region="us")
        ```

        ## Import

        Domain credential can be imported using `region:email` via `import` command. Region has to be chosen from `eu` or `us` (when no selection `us` is applied).

        Password is always exported to `null`.

        hcl

        ```sh
        $ pulumi import mailgun:index/domainCredential:DomainCredential test us:test@domain.com
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain: The domain to add credential of Mailgun.
        :param pulumi.Input[_builtins.str] login: The local-part of the email address to create.
        :param pulumi.Input[_builtins.str] password: Password for user authentication.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DomainCredentialArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Mailgun domain credential resource. This can be used to create and manage credential in domain of Mailgun.

        > **Note:** Please note that starting of v0.6.1 due to using new Mailgun Client API (v4), there is no possibility to retrieve previously created secrets via API. In order get it worked, it's recommended to mark `password` as ignored under `lifecycle` block. See below.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_mailgun as mailgun

        # Create a new Mailgun credential
        foobar = mailgun.DomainCredential("foobar",
            domain="toto.com",
            login="test",
            password="supersecretpassword1234",
            region="us")
        ```

        ## Import

        Domain credential can be imported using `region:email` via `import` command. Region has to be chosen from `eu` or `us` (when no selection `us` is applied).

        Password is always exported to `null`.

        hcl

        ```sh
        $ pulumi import mailgun:index/domainCredential:DomainCredential test us:test@domain.com
        ```

        :param str resource_name: The name of the resource.
        :param DomainCredentialArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainCredentialArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 login: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainCredentialArgs.__new__(DomainCredentialArgs)

            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            if login is None and not opts.urn:
                raise TypeError("Missing required property 'login'")
            __props__.__dict__["login"] = login
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["region"] = region
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(DomainCredential, __self__).__init__(
            'mailgun:index/domainCredential:DomainCredential',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain: Optional[pulumi.Input[_builtins.str]] = None,
            login: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'DomainCredential':
        """
        Get an existing DomainCredential resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain: The domain to add credential of Mailgun.
        :param pulumi.Input[_builtins.str] login: The local-part of the email address to create.
        :param pulumi.Input[_builtins.str] password: Password for user authentication.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainCredentialState.__new__(_DomainCredentialState)

        __props__.__dict__["domain"] = domain
        __props__.__dict__["login"] = login
        __props__.__dict__["password"] = password
        __props__.__dict__["region"] = region
        return DomainCredential(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Output[_builtins.str]:
        """
        The domain to add credential of Mailgun.
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter
    def login(self) -> pulumi.Output[_builtins.str]:
        """
        The local-part of the email address to create.
        """
        return pulumi.get(self, "login")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[_builtins.str]:
        """
        Password for user authentication.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DomainArgs', 'Domain']

@pulumi.input_type
class DomainArgs:
    def __init__(__self__, *,
                 click_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
                 dkim_key_size: Optional[pulumi.Input[_builtins.int]] = None,
                 dkim_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 force_dkim_authority: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 open_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 smtp_password: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_action: Optional[pulumi.Input[_builtins.str]] = None,
                 web_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 wildcard: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a Domain resource.
        :param pulumi.Input[_builtins.bool] click_tracking: (Enum: `yes` or `no`) The click tracking settings for the domain. Default: `no`
        :param pulumi.Input[_builtins.int] dkim_key_size: The length of your domain’s generated DKIM key. Default value is `1024`.
        :param pulumi.Input[_builtins.str] dkim_selector: The name of your DKIM selector if you want to specify it whereas MailGun will make it's own choice.
        :param pulumi.Input[_builtins.bool] force_dkim_authority: If set to true, the domain will be the DKIM authority for itself even if the root domain is registered on the same mailgun account. If set to false, the domain will have the same DKIM authority as the root domain registered on the same mailgun account. The default is `false`.
        :param pulumi.Input[_builtins.str] name: The domain to add to Mailgun
        :param pulumi.Input[_builtins.bool] open_tracking: (Enum: `yes` or `no`) The open tracking settings for the domain. Default: `no`
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        :param pulumi.Input[_builtins.str] smtp_password: Password for SMTP authentication
        :param pulumi.Input[_builtins.str] spam_action: `disabled` or `tag` Disable, no spam
               filtering will occur for inbound messages. Tag, messages
               will be tagged with a spam header. Default value is `disabled`.
        :param pulumi.Input[_builtins.str] web_scheme: (`http` or `https`) The tracking web scheme. Default: `http`
        :param pulumi.Input[_builtins.bool] wildcard: Boolean that determines whether
               the domain will accept email for sub-domains.
        """
        if click_tracking is not None:
            pulumi.set(__self__, "click_tracking", click_tracking)
        if dkim_key_size is not None:
            pulumi.set(__self__, "dkim_key_size", dkim_key_size)
        if dkim_selector is not None:
            pulumi.set(__self__, "dkim_selector", dkim_selector)
        if force_dkim_authority is not None:
            pulumi.set(__self__, "force_dkim_authority", force_dkim_authority)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if open_tracking is not None:
            pulumi.set(__self__, "open_tracking", open_tracking)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if smtp_password is not None:
            pulumi.set(__self__, "smtp_password", smtp_password)
        if spam_action is not None:
            pulumi.set(__self__, "spam_action", spam_action)
        if web_scheme is not None:
            pulumi.set(__self__, "web_scheme", web_scheme)
        if wildcard is not None:
            pulumi.set(__self__, "wildcard", wildcard)

    @_builtins.property
    @pulumi.getter(name="clickTracking")
    def click_tracking(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (Enum: `yes` or `no`) The click tracking settings for the domain. Default: `no`
        """
        return pulumi.get(self, "click_tracking")

    @click_tracking.setter
    def click_tracking(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "click_tracking", value)

    @_builtins.property
    @pulumi.getter(name="dkimKeySize")
    def dkim_key_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The length of your domain’s generated DKIM key. Default value is `1024`.
        """
        return pulumi.get(self, "dkim_key_size")

    @dkim_key_size.setter
    def dkim_key_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "dkim_key_size", value)

    @_builtins.property
    @pulumi.getter(name="dkimSelector")
    def dkim_selector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of your DKIM selector if you want to specify it whereas MailGun will make it's own choice.
        """
        return pulumi.get(self, "dkim_selector")

    @dkim_selector.setter
    def dkim_selector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dkim_selector", value)

    @_builtins.property
    @pulumi.getter(name="forceDkimAuthority")
    def force_dkim_authority(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to true, the domain will be the DKIM authority for itself even if the root domain is registered on the same mailgun account. If set to false, the domain will have the same DKIM authority as the root domain registered on the same mailgun account. The default is `false`.
        """
        return pulumi.get(self, "force_dkim_authority")

    @force_dkim_authority.setter
    def force_dkim_authority(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_dkim_authority", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain to add to Mailgun
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="openTracking")
    def open_tracking(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (Enum: `yes` or `no`) The open tracking settings for the domain. Default: `no`
        """
        return pulumi.get(self, "open_tracking")

    @open_tracking.setter
    def open_tracking(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "open_tracking", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="smtpPassword")
    def smtp_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for SMTP authentication
        """
        return pulumi.get(self, "smtp_password")

    @smtp_password.setter
    def smtp_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "smtp_password", value)

    @_builtins.property
    @pulumi.getter(name="spamAction")
    def spam_action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `disabled` or `tag` Disable, no spam
        filtering will occur for inbound messages. Tag, messages
        will be tagged with a spam header. Default value is `disabled`.
        """
        return pulumi.get(self, "spam_action")

    @spam_action.setter
    def spam_action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "spam_action", value)

    @_builtins.property
    @pulumi.getter(name="webScheme")
    def web_scheme(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (`http` or `https`) The tracking web scheme. Default: `http`
        """
        return pulumi.get(self, "web_scheme")

    @web_scheme.setter
    def web_scheme(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_scheme", value)

    @_builtins.property
    @pulumi.getter
    def wildcard(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that determines whether
        the domain will accept email for sub-domains.
        """
        return pulumi.get(self, "wildcard")

    @wildcard.setter
    def wildcard(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "wildcard", value)


@pulumi.input_type
class _DomainState:
    def __init__(__self__, *,
                 click_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
                 dkim_key_size: Optional[pulumi.Input[_builtins.int]] = None,
                 dkim_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 force_dkim_authority: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 open_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
                 receiving_records: Optional[pulumi.Input[Sequence[pulumi.Input['DomainReceivingRecordArgs']]]] = None,
                 receiving_records_sets: Optional[pulumi.Input[Sequence[pulumi.Input['DomainReceivingRecordsSetArgs']]]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 sending_records: Optional[pulumi.Input[Sequence[pulumi.Input['DomainSendingRecordArgs']]]] = None,
                 sending_records_sets: Optional[pulumi.Input[Sequence[pulumi.Input['DomainSendingRecordsSetArgs']]]] = None,
                 smtp_login: Optional[pulumi.Input[_builtins.str]] = None,
                 smtp_password: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_action: Optional[pulumi.Input[_builtins.str]] = None,
                 web_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 wildcard: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Domain resources.
        :param pulumi.Input[_builtins.bool] click_tracking: (Enum: `yes` or `no`) The click tracking settings for the domain. Default: `no`
        :param pulumi.Input[_builtins.int] dkim_key_size: The length of your domain’s generated DKIM key. Default value is `1024`.
        :param pulumi.Input[_builtins.str] dkim_selector: The name of your DKIM selector if you want to specify it whereas MailGun will make it's own choice.
        :param pulumi.Input[_builtins.bool] force_dkim_authority: If set to true, the domain will be the DKIM authority for itself even if the root domain is registered on the same mailgun account. If set to false, the domain will have the same DKIM authority as the root domain registered on the same mailgun account. The default is `false`.
        :param pulumi.Input[_builtins.str] name: The domain to add to Mailgun
        :param pulumi.Input[_builtins.bool] open_tracking: (Enum: `yes` or `no`) The open tracking settings for the domain. Default: `no`
        :param pulumi.Input[Sequence[pulumi.Input['DomainReceivingRecordArgs']]] receiving_records: A list of DNS records for receiving validation.  **Deprecated** Use `receiving_records_set` instead.
        :param pulumi.Input[Sequence[pulumi.Input['DomainReceivingRecordsSetArgs']]] receiving_records_sets: A set of DNS records for receiving validation.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        :param pulumi.Input[Sequence[pulumi.Input['DomainSendingRecordArgs']]] sending_records: A list of DNS records for sending validation. **Deprecated** Use `sending_records_set` instead.
        :param pulumi.Input[Sequence[pulumi.Input['DomainSendingRecordsSetArgs']]] sending_records_sets: A set of DNS records for sending validation.
        :param pulumi.Input[_builtins.str] smtp_login: The login email for the SMTP server.
        :param pulumi.Input[_builtins.str] smtp_password: Password for SMTP authentication
        :param pulumi.Input[_builtins.str] spam_action: `disabled` or `tag` Disable, no spam
               filtering will occur for inbound messages. Tag, messages
               will be tagged with a spam header. Default value is `disabled`.
        :param pulumi.Input[_builtins.str] web_scheme: (`http` or `https`) The tracking web scheme. Default: `http`
        :param pulumi.Input[_builtins.bool] wildcard: Boolean that determines whether
               the domain will accept email for sub-domains.
        """
        if click_tracking is not None:
            pulumi.set(__self__, "click_tracking", click_tracking)
        if dkim_key_size is not None:
            pulumi.set(__self__, "dkim_key_size", dkim_key_size)
        if dkim_selector is not None:
            pulumi.set(__self__, "dkim_selector", dkim_selector)
        if force_dkim_authority is not None:
            pulumi.set(__self__, "force_dkim_authority", force_dkim_authority)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if open_tracking is not None:
            pulumi.set(__self__, "open_tracking", open_tracking)
        if receiving_records is not None:
            warnings.warn("""Use `receiving_records_set` instead.""", DeprecationWarning)
            pulumi.log.warn("""receiving_records is deprecated: Use `receiving_records_set` instead.""")
        if receiving_records is not None:
            pulumi.set(__self__, "receiving_records", receiving_records)
        if receiving_records_sets is not None:
            pulumi.set(__self__, "receiving_records_sets", receiving_records_sets)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if sending_records is not None:
            warnings.warn("""Use `sending_records_set` instead.""", DeprecationWarning)
            pulumi.log.warn("""sending_records is deprecated: Use `sending_records_set` instead.""")
        if sending_records is not None:
            pulumi.set(__self__, "sending_records", sending_records)
        if sending_records_sets is not None:
            pulumi.set(__self__, "sending_records_sets", sending_records_sets)
        if smtp_login is not None:
            pulumi.set(__self__, "smtp_login", smtp_login)
        if smtp_password is not None:
            pulumi.set(__self__, "smtp_password", smtp_password)
        if spam_action is not None:
            pulumi.set(__self__, "spam_action", spam_action)
        if web_scheme is not None:
            pulumi.set(__self__, "web_scheme", web_scheme)
        if wildcard is not None:
            pulumi.set(__self__, "wildcard", wildcard)

    @_builtins.property
    @pulumi.getter(name="clickTracking")
    def click_tracking(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (Enum: `yes` or `no`) The click tracking settings for the domain. Default: `no`
        """
        return pulumi.get(self, "click_tracking")

    @click_tracking.setter
    def click_tracking(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "click_tracking", value)

    @_builtins.property
    @pulumi.getter(name="dkimKeySize")
    def dkim_key_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The length of your domain’s generated DKIM key. Default value is `1024`.
        """
        return pulumi.get(self, "dkim_key_size")

    @dkim_key_size.setter
    def dkim_key_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "dkim_key_size", value)

    @_builtins.property
    @pulumi.getter(name="dkimSelector")
    def dkim_selector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of your DKIM selector if you want to specify it whereas MailGun will make it's own choice.
        """
        return pulumi.get(self, "dkim_selector")

    @dkim_selector.setter
    def dkim_selector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dkim_selector", value)

    @_builtins.property
    @pulumi.getter(name="forceDkimAuthority")
    def force_dkim_authority(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        If set to true, the domain will be the DKIM authority for itself even if the root domain is registered on the same mailgun account. If set to false, the domain will have the same DKIM authority as the root domain registered on the same mailgun account. The default is `false`.
        """
        return pulumi.get(self, "force_dkim_authority")

    @force_dkim_authority.setter
    def force_dkim_authority(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_dkim_authority", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain to add to Mailgun
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="openTracking")
    def open_tracking(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (Enum: `yes` or `no`) The open tracking settings for the domain. Default: `no`
        """
        return pulumi.get(self, "open_tracking")

    @open_tracking.setter
    def open_tracking(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "open_tracking", value)

    @_builtins.property
    @pulumi.getter(name="receivingRecords")
    @_utilities.deprecated("""Use `receiving_records_set` instead.""")
    def receiving_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainReceivingRecordArgs']]]]:
        """
        A list of DNS records for receiving validation.  **Deprecated** Use `receiving_records_set` instead.
        """
        return pulumi.get(self, "receiving_records")

    @receiving_records.setter
    def receiving_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainReceivingRecordArgs']]]]):
        pulumi.set(self, "receiving_records", value)

    @_builtins.property
    @pulumi.getter(name="receivingRecordsSets")
    def receiving_records_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainReceivingRecordsSetArgs']]]]:
        """
        A set of DNS records for receiving validation.
        """
        return pulumi.get(self, "receiving_records_sets")

    @receiving_records_sets.setter
    def receiving_records_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainReceivingRecordsSetArgs']]]]):
        pulumi.set(self, "receiving_records_sets", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="sendingRecords")
    @_utilities.deprecated("""Use `sending_records_set` instead.""")
    def sending_records(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainSendingRecordArgs']]]]:
        """
        A list of DNS records for sending validation. **Deprecated** Use `sending_records_set` instead.
        """
        return pulumi.get(self, "sending_records")

    @sending_records.setter
    def sending_records(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainSendingRecordArgs']]]]):
        pulumi.set(self, "sending_records", value)

    @_builtins.property
    @pulumi.getter(name="sendingRecordsSets")
    def sending_records_sets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DomainSendingRecordsSetArgs']]]]:
        """
        A set of DNS records for sending validation.
        """
        return pulumi.get(self, "sending_records_sets")

    @sending_records_sets.setter
    def sending_records_sets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DomainSendingRecordsSetArgs']]]]):
        pulumi.set(self, "sending_records_sets", value)

    @_builtins.property
    @pulumi.getter(name="smtpLogin")
    def smtp_login(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The login email for the SMTP server.
        """
        return pulumi.get(self, "smtp_login")

    @smtp_login.setter
    def smtp_login(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "smtp_login", value)

    @_builtins.property
    @pulumi.getter(name="smtpPassword")
    def smtp_password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password for SMTP authentication
        """
        return pulumi.get(self, "smtp_password")

    @smtp_password.setter
    def smtp_password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "smtp_password", value)

    @_builtins.property
    @pulumi.getter(name="spamAction")
    def spam_action(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `disabled` or `tag` Disable, no spam
        filtering will occur for inbound messages. Tag, messages
        will be tagged with a spam header. Default value is `disabled`.
        """
        return pulumi.get(self, "spam_action")

    @spam_action.setter
    def spam_action(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "spam_action", value)

    @_builtins.property
    @pulumi.getter(name="webScheme")
    def web_scheme(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (`http` or `https`) The tracking web scheme. Default: `http`
        """
        return pulumi.get(self, "web_scheme")

    @web_scheme.setter
    def web_scheme(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "web_scheme", value)

    @_builtins.property
    @pulumi.getter
    def wildcard(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean that determines whether
        the domain will accept email for sub-domains.
        """
        return pulumi.get(self, "wildcard")

    @wildcard.setter
    def wildcard(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "wildcard", value)


@pulumi.type_token("mailgun:index/domain:Domain")
class Domain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 click_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
                 dkim_key_size: Optional[pulumi.Input[_builtins.int]] = None,
                 dkim_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 force_dkim_authority: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 open_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 smtp_password: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_action: Optional[pulumi.Input[_builtins.str]] = None,
                 web_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 wildcard: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Provides a Mailgun App resource. This can be used to
        create and manage applications on Mailgun.

        After DNS records are set, domain verification should be triggered manually using [PUT /domains/\\<domain\\>/verify](https://documentation.mailgun.com/en/latest/api-domains.html#domains)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_mailgun as mailgun

        # Create a new Mailgun domain
        default = mailgun.Domain("default",
            name="test.example.com",
            region="us",
            spam_action="disabled",
            smtp_password="supersecretpassword1234",
            dkim_key_size=1024)
        ```

        ## Import

        Domains can be imported using `region:domain_name` via `import` command. Region has to be chosen from `eu` or `us` (when no selection `us` is applied).

        hcl

        ```sh
        $ pulumi import mailgun:index/domain:Domain test us:example.domain.com
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] click_tracking: (Enum: `yes` or `no`) The click tracking settings for the domain. Default: `no`
        :param pulumi.Input[_builtins.int] dkim_key_size: The length of your domain’s generated DKIM key. Default value is `1024`.
        :param pulumi.Input[_builtins.str] dkim_selector: The name of your DKIM selector if you want to specify it whereas MailGun will make it's own choice.
        :param pulumi.Input[_builtins.bool] force_dkim_authority: If set to true, the domain will be the DKIM authority for itself even if the root domain is registered on the same mailgun account. If set to false, the domain will have the same DKIM authority as the root domain registered on the same mailgun account. The default is `false`.
        :param pulumi.Input[_builtins.str] name: The domain to add to Mailgun
        :param pulumi.Input[_builtins.bool] open_tracking: (Enum: `yes` or `no`) The open tracking settings for the domain. Default: `no`
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        :param pulumi.Input[_builtins.str] smtp_password: Password for SMTP authentication
        :param pulumi.Input[_builtins.str] spam_action: `disabled` or `tag` Disable, no spam
               filtering will occur for inbound messages. Tag, messages
               will be tagged with a spam header. Default value is `disabled`.
        :param pulumi.Input[_builtins.str] web_scheme: (`http` or `https`) The tracking web scheme. Default: `http`
        :param pulumi.Input[_builtins.bool] wildcard: Boolean that determines whether
               the domain will accept email for sub-domains.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DomainArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Mailgun App resource. This can be used to
        create and manage applications on Mailgun.

        After DNS records are set, domain verification should be triggered manually using [PUT /domains/\\<domain\\>/verify](https://documentation.mailgun.com/en/latest/api-domains.html#domains)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_mailgun as mailgun

        # Create a new Mailgun domain
        default = mailgun.Domain("default",
            name="test.example.com",
            region="us",
            spam_action="disabled",
            smtp_password="supersecretpassword1234",
            dkim_key_size=1024)
        ```

        ## Import

        Domains can be imported using `region:domain_name` via `import` command. Region has to be chosen from `eu` or `us` (when no selection `us` is applied).

        hcl

        ```sh
        $ pulumi import mailgun:index/domain:Domain test us:example.domain.com
        ```

        :param str resource_name: The name of the resource.
        :param DomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 click_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
                 dkim_key_size: Optional[pulumi.Input[_builtins.int]] = None,
                 dkim_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 force_dkim_authority: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 open_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 smtp_password: Optional[pulumi.Input[_builtins.str]] = None,
                 spam_action: Optional[pulumi.Input[_builtins.str]] = None,
                 web_scheme: Optional[pulumi.Input[_builtins.str]] = None,
                 wildcard: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainArgs.__new__(DomainArgs)

            __props__.__dict__["click_tracking"] = click_tracking
            __props__.__dict__["dkim_key_size"] = dkim_key_size
            __props__.__dict__["dkim_selector"] = dkim_selector
            __props__.__dict__["force_dkim_authority"] = force_dkim_authority
            __props__.__dict__["name"] = name
            __props__.__dict__["open_tracking"] = open_tracking
            __props__.__dict__["region"] = region
            __props__.__dict__["smtp_password"] = None if smtp_password is None else pulumi.Output.secret(smtp_password)
            __props__.__dict__["spam_action"] = spam_action
            __props__.__dict__["web_scheme"] = web_scheme
            __props__.__dict__["wildcard"] = wildcard
            __props__.__dict__["receiving_records"] = None
            __props__.__dict__["receiving_records_sets"] = None
            __props__.__dict__["sending_records"] = None
            __props__.__dict__["sending_records_sets"] = None
            __props__.__dict__["smtp_login"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["smtpPassword"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Domain, __self__).__init__(
            'mailgun:index/domain:Domain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            click_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
            dkim_key_size: Optional[pulumi.Input[_builtins.int]] = None,
            dkim_selector: Optional[pulumi.Input[_builtins.str]] = None,
            force_dkim_authority: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            open_tracking: Optional[pulumi.Input[_builtins.bool]] = None,
            receiving_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainReceivingRecordArgs', 'DomainReceivingRecordArgsDict']]]]] = None,
            receiving_records_sets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainReceivingRecordsSetArgs', 'DomainReceivingRecordsSetArgsDict']]]]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            sending_records: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainSendingRecordArgs', 'DomainSendingRecordArgsDict']]]]] = None,
            sending_records_sets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DomainSendingRecordsSetArgs', 'DomainSendingRecordsSetArgsDict']]]]] = None,
            smtp_login: Optional[pulumi.Input[_builtins.str]] = None,
            smtp_password: Optional[pulumi.Input[_builtins.str]] = None,
            spam_action: Optional[pulumi.Input[_builtins.str]] = None,
            web_scheme: Optional[pulumi.Input[_builtins.str]] = None,
            wildcard: Optional[pulumi.Input[_builtins.bool]] = None) -> 'Domain':
        """
        Get an existing Domain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] click_tracking: (Enum: `yes` or `no`) The click tracking settings for the domain. Default: `no`
        :param pulumi.Input[_builtins.int] dkim_key_size: The length of your domain’s generated DKIM key. Default value is `1024`.
        :param pulumi.Input[_builtins.str] dkim_selector: The name of your DKIM selector if you want to specify it whereas MailGun will make it's own choice.
        :param pulumi.Input[_builtins.bool] force_dkim_authority: If set to true, the domain will be the DKIM authority for itself even if the root domain is registered on the same mailgun account. If set to false, the domain will have the same DKIM authority as the root domain registered on the same mailgun account. The default is `false`.
        :param pulumi.Input[_builtins.str] name: The domain to add to Mailgun
        :param pulumi.Input[_builtins.bool] open_tracking: (Enum: `yes` or `no`) The open tracking settings for the domain. Default: `no`
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainReceivingRecordArgs', 'DomainReceivingRecordArgsDict']]]] receiving_records: A list of DNS records for receiving validation.  **Deprecated** Use `receiving_records_set` instead.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainReceivingRecordsSetArgs', 'DomainReceivingRecordsSetArgsDict']]]] receiving_records_sets: A set of DNS records for receiving validation.
        :param pulumi.Input[_builtins.str] region: The region where domain will be created. Default value is `us`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainSendingRecordArgs', 'DomainSendingRecordArgsDict']]]] sending_records: A list of DNS records for sending validation. **Deprecated** Use `sending_records_set` instead.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DomainSendingRecordsSetArgs', 'DomainSendingRecordsSetArgsDict']]]] sending_records_sets: A set of DNS records for sending validation.
        :param pulumi.Input[_builtins.str] smtp_login: The login email for the SMTP server.
        :param pulumi.Input[_builtins.str] smtp_password: Password for SMTP authentication
        :param pulumi.Input[_builtins.str] spam_action: `disabled` or `tag` Disable, no spam
               filtering will occur for inbound messages. Tag, messages
               will be tagged with a spam header. Default value is `disabled`.
        :param pulumi.Input[_builtins.str] web_scheme: (`http` or `https`) The tracking web scheme. Default: `http`
        :param pulumi.Input[_builtins.bool] wildcard: Boolean that determines whether
               the domain will accept email for sub-domains.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainState.__new__(_DomainState)

        __props__.__dict__["click_tracking"] = click_tracking
        __props__.__dict__["dkim_key_size"] = dkim_key_size
        __props__.__dict__["dkim_selector"] = dkim_selector
        __props__.__dict__["force_dkim_authority"] = force_dkim_authority
        __props__.__dict__["name"] = name
        __props__.__dict__["open_tracking"] = open_tracking
        __props__.__dict__["receiving_records"] = receiving_records
        __props__.__dict__["receiving_records_sets"] = receiving_records_sets
        __props__.__dict__["region"] = region
        __props__.__dict__["sending_records"] = sending_records
        __props__.__dict__["sending_records_sets"] = sending_records_sets
        __props__.__dict__["smtp_login"] = smtp_login
        __props__.__dict__["smtp_password"] = smtp_password
        __props__.__dict__["spam_action"] = spam_action
        __props__.__dict__["web_scheme"] = web_scheme
        __props__.__dict__["wildcard"] = wildcard
        return Domain(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clickTracking")
    def click_tracking(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        (Enum: `yes` or `no`) The click tracking settings for the domain. Default: `no`
        """
        return pulumi.get(self, "click_tracking")

    @_builtins.property
    @pulumi.getter(name="dkimKeySize")
    def dkim_key_size(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The length of your domain’s generated DKIM key. Default value is `1024`.
        """
        return pulumi.get(self, "dkim_key_size")

    @_builtins.property
    @pulumi.getter(name="dkimSelector")
    def dkim_selector(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of your DKIM selector if you want to specify it whereas MailGun will make it's own choice.
        """
        return pulumi.get(self, "dkim_selector")

    @_builtins.property
    @pulumi.getter(name="forceDkimAuthority")
    def force_dkim_authority(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        If set to true, the domain will be the DKIM authority for itself even if the root domain is registered on the same mailgun account. If set to false, the domain will have the same DKIM authority as the root domain registered on the same mailgun account. The default is `false`.
        """
        return pulumi.get(self, "force_dkim_authority")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The domain to add to Mailgun
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="openTracking")
    def open_tracking(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        (Enum: `yes` or `no`) The open tracking settings for the domain. Default: `no`
        """
        return pulumi.get(self, "open_tracking")

    @_builtins.property
    @pulumi.getter(name="receivingRecords")
    @_utilities.deprecated("""Use `receiving_records_set` instead.""")
    def receiving_records(self) -> pulumi.Output[Sequence['outputs.DomainReceivingRecord']]:
        """
        A list of DNS records for receiving validation.  **Deprecated** Use `receiving_records_set` instead.
        """
        return pulumi.get(self, "receiving_records")

    @_builtins.property
    @pulumi.getter(name="receivingRecordsSets")
    def receiving_records_sets(self) -> pulumi.Output[Sequence['outputs.DomainReceivingRecordsSet']]:
        """
        A set of DNS records for receiving validation.
        """
        return pulumi.get(self, "receiving_records_sets")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The region where domain will be created. Default value is `us`.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="sendingRecords")
    @_utilities.deprecated("""Use `sending_records_set` instead.""")
    def sending_records(self) -> pulumi.Output[Sequence['outputs.DomainSendingRecord']]:
        """
        A list of DNS records for sending validation. **Deprecated** Use `sending_records_set` instead.
        """
        return pulumi.get(self, "sending_records")

    @_builtins.property
    @pulumi.getter(name="sendingRecordsSets")
    def sending_records_sets(self) -> pulumi.Output[Sequence['outputs.DomainSendingRecordsSet']]:
        """
        A set of DNS records for sending validation.
        """
        return pulumi.get(self, "sending_records_sets")

    @_builtins.property
    @pulumi.getter(name="smtpLogin")
    def smtp_login(self) -> pulumi.Output[_builtins.str]:
        """
        The login email for the SMTP server.
        """
        return pulumi.get(self, "smtp_login")

    @_builtins.property
    @pulumi.getter(name="smtpPassword")
    def smtp_password(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Password for SMTP authentication
        """
        return pulumi.get(self, "smtp_password")

    @_builtins.property
    @pulumi.getter(name="spamAction")
    def spam_action(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `disabled` or `tag` Disable, no spam
        filtering will occur for inbound messages. Tag, messages
        will be tagged with a spam header. Default value is `disabled`.
        """
        return pulumi.get(self, "spam_action")

    @_builtins.property
    @pulumi.getter(name="webScheme")
    def web_scheme(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (`http` or `https`) The tracking web scheme. Default: `http`
        """
        return pulumi.get(self, "web_scheme")

    @_builtins.property
    @pulumi.getter
    def wildcard(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Boolean that determines whether
        the domain will accept email for sub-domains.
        """
        return pulumi.get(self, "wildcard")

